@@ -1,4 +1,5 @@
 context("text2vec iterators")
+doParallel::registerDoParallel(2)
 
 N = 100
 ########################################
@@ -21,7 +22,7 @@ test_that("ifiles", {
   it = ifiles(c(temp_file_1, temp_file_2))
   it2 = itoken(it, preprocessor = tolower, tokenizer = word_tokenizer, progressbar = FALSE)
   v = create_vocabulary(it2)
-  expect_equal(nrow(v), 7261)
+  expect_equal(nrow(v), 7448)
   v2 = create_vocabulary(it2)
   expect_equal(v, v2)
   dtm = create_dtm(it2, hash_vectorizer())
@@ -33,8 +34,8 @@ test_that("ifiles", {
 test_that("ifiles_parallel", {
   it = ifiles_parallel(c(temp_file_1, temp_file_2))
   it2 = itoken_parallel(it, preprocessor = tolower, tokenizer = word_tokenizer, progressbar = FALSE)
-  expect_warning(v <- create_vocabulary(it2))
-  expect_equal(nrow(v), 7261)
+  v = create_vocabulary(it2)
+  expect_equal(nrow(v), 7448)
   v2 = create_vocabulary(it2)
   expect_equal(v, v2)
   dtm = create_dtm(it2, hash_vectorizer())
@@ -45,29 +46,38 @@ test_that("ifiles_parallel", {
 
 
 test_that("idir", {
+  # have no clue why it fails on CRAN win-builder
+  skip_on_cran()
   it = idir(path = tmp_dir)
   it2 = itoken(it, preprocessor = tolower, tokenizer = word_tokenizer, progressbar = FALSE)
   v = create_vocabulary(it2)
-  expect_equal(nrow(v), 7261)
+  expect_equal(nrow(v), 7448)
 })
 
-# test_that("ilines", {
-#   it = ilines(con = temp_file_1, n = 10)
-#   it2 = itoken(it, preprocessor = tolower, tokenizer = word_tokenizer)
-#   v = create_vocabulary(it2)
-#   expect_equal(nrow(v), 4464)
-# })
-
 test_that("itoken character", {
   it2 = itoken(txt_1, preprocessor = tolower, tokenizer = word_tokenizer, progressbar = FALSE)
   v = create_vocabulary(it2)
-  expect_equal(nrow(v), 4464)
+  expect_equal(nrow(v), 4562)
 })
 
 test_that("itoken character parallel", {
   it2 = itoken_parallel(txt_1, preprocessor = tolower, tokenizer = word_tokenizer)
   v = create_vocabulary(it2)
-  expect_equal(nrow(v), 4464)
+  expect_equal(nrow(v), 4562)
+})
+
+test_that("itoken list parallel", {
+  tokens = word_tokenizer(tolower(txt_1))
+  it2 = itoken_parallel(tokens)
+  v = create_vocabulary(it2)
+  expect_equal(nrow(v), 4562)
+})
+
+test_that("itoken list non-character", {
+  tokens = list(1:10, 5:15)
+  it2 = itoken_parallel(tokens)
+  v = create_vocabulary(it2)
+  expect_equal(setdiff(as.character(1:15), v$term), character(0))
 })
 
 ########################################
