@@ -8,8 +8,8 @@ tokens = word_tokenizer(tokens)
 ids = movie_review[['id']][train_ind]
 it = itoken(tokens, ids = ids, progressbar = FALSE)
 
-vocab = create_vocabulary(it) %>%
-  prune_vocabulary(term_count_min = 5, doc_proportion_max = 0.5)
+vocab = create_vocabulary(it)
+vocab = prune_vocabulary(vocab, term_count_min = 5, doc_proportion_max = 0.5)
 
 dtm = create_dtm(it, vocab_vectorizer(vocab))
 
