@@ -11,20 +11,12 @@ txt_first_10 = c("with", "all", "this", "stuff",
 
 test_that("word_tokenizer ", {
   tokens = word_tokenizer(txt)[[1]]
-  expect_equal(length(tokens), 446)
+  expect_equal(length(tokens), 438)
   expect_equal(tokens[1:10], txt_first_10)
   # non ASCII symbols
   tokens = word_tokenizer("one, two. Three! four")[[1]]
   expect_equal(tokens, c("one", "two", "Three", "four"))
 })
-test_that("regexp_tokenizer ", {
-  tokens = regexp_tokenizer(txt, pattern = "[[:punct:]]|\\s+")[[1]]
-  expect_equal(length(tokens), 499)
-  expect_equal(tokens[1:10], txt_first_10)
-  # non ASCII symbols
-  tokens = regexp_tokenizer("one, two. Three! four", "[[:punct:]]|\\s+")[[1]]
-  expect_equal(tokens, c("one", "", "two", "", "Three", "", "four"))
-})
 
 test_that("space_tokenizer ", {
   tokens = space_tokenizer(txt)[[1]]
